==> enterprisemodules-db2_config-0.1.3.tar.gz: enterprisemodules-db2_config-0.1.3/lib/puppet/type/db2_tablespace.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_tablespace) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access
  include PuppetX::EnterpriseModules::Db2::Commands

  desc <<-DESC
  This resource allows you to manage a DB2 tablespace. Here is an example on how to use this:

      db2_tablespace { 'db2inst1/MYDB/USERSPACE1':
        ensure                => 'present',
      }


  TODO: Extend the example

  DESC

  to_get_raw_resources do
    tablespaces = []
    db2_instance_names.each do |instance|
      databases_names_on(instance).each do |database|
        tablespaces += tablespaces_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    tablespaces
  end

  ensurable

  on_create do
    [:db2, "create tablespace #{tablespace_name}", { :instance => instance_name, :database => database_name }]
  end

  on_modify do
    # TODO: Implement this
  end

  on_destroy do
    [:db2, "drop tablespace #{tablespace_name}", { :instance => instance_name, :database => database_name }]
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :tablespace_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :tablespace_name

  property  :owner
  property  :ownertype
  property  :create_time
  property  :tbspaceid
  property  :tbspacetype
  property  :datatype
  property  :extentsize
  property  :prefetchsize
  property  :overhead
  property  :transferrate
  property  :writeoverhead
  property  :writetransferrate
  # property  :pagesize
  property  :dbpgname
  property  :bufferpoolid
  property  :drop_recovery
  property  :ngname
  property  :definer
  property  :datatag
  property  :sgname
  property  :sgid
  property  :effectiveprefetchsize
  property  :cachingtier
  property  :remarks
end

==> enterprisemodules-db2_config-0.3.0.tar.gz: enterprisemodules-db2_config-0.3.0/lib/puppet/type/db2_tablespace.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_tablespace) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access
  include PuppetX::EnterpriseModules::Db2::Commands

  desc <<-DESC
  This resource allows you to manage a DB2 tablespace. Here is an example on how to use this:

      db2_tablespace { 'db2inst1/MYDB/USERSPACE1':
        ensure                => 'present',
      }


  TODO: Extend the example

  DESC

  to_get_raw_resources do
    tablespaces = []
    db2_instance_names.each do |instance|
      primary_database_names_on(instance).each do |database|
        tablespaces += tablespaces_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    tablespaces
  end

  ensurable

  on_create do
    [:db2, "create tablespace #{tablespace_name}", { :instance => instance_name, :database => database_name }]
  end

  on_modify do
    # TODO: Implement this
  end

  on_destroy do
    [:db2, "drop tablespace #{tablespace_name}", { :instance => instance_name, :database => database_name }]
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :tablespace_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :tablespace_name

  property  :owner
  property  :ownertype
  property  :create_time
  property  :tbspaceid
  property  :tbspacetype
  property  :datatype
  property  :extentsize
  property  :prefetchsize
  property  :overhead
  property  :transferrate
  property  :writeoverhead
  property  :writetransferrate
  # property  :pagesize
  property  :dbpgname
  property  :bufferpoolid
  property  :drop_recovery
  property  :ngname
  property  :definer
  property  :datatag
  property  :sgname
  property  :sgid
  property  :effectiveprefetchsize
  property  :cachingtier
  property  :remarks
end
